# TODO check that no license information gets lost
{ fetchurl, stdenv, python, go, cmake, vim, vimUtils, perl, ruby, unzip
, which, fetchgit, llvmPackages
, xkb_switch, rustracerd, fzf
, python3, boost, icu
, Cocoa ? null
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# TL;DR
# Add your plugin to ./vim-plugin-names
# Regenerate via `nix-build -Q -A vimPlugins.pluginnames2nix; ./result/bin/vim-plugin-names-to-nix`
# Copy the generated expression(s) into this file.
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # aliasess
  "sourcemap.vim"     = sourcemap;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  YouCompleteMe       = youcompleteme;
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized    = Solarized;
  colorsamplerpack    = Colour_Sampler_Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  css_color_5056      = vim-css-color;
  ctrlp               = ctrlp-vim;
  easy-align          = vim-easy-align;
  easymotion          = vim-easymotion;
  eighties            = vim-eighties;
  ghc-mod-vim         = ghcmod;
  gist-vim            = Gist;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellconceal      = vim-haskellconceal;
  haskellConcealPlus  = vim-haskellConcealPlus;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = Hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neosnippet          = neosnippet-vim;
  nerdcommenter       = The_NERD_Commenter;
  nerdtree            = The_NERD_tree;
  polyglot            = vim-polyglot;
  quickrun            = vim-quickrun;
  repeat              = vim-repeat;
  signature           = vim-signature;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  supertab            = Supertab;
  syntastic           = Syntastic;
  tabular             = Tabular;
  tagbar              = Tagbar;
  thumbnail           = thumbnail-vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  unite               = unite-vim;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  watchdogs           = vim-watchdogs;
  webapi-vim          = WebAPI;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing;

  fzfWrapper = buildVimPluginFrom2Nix {
    name = fzf.name;
    src = fzf.src;
    dependencies = [];
  };

  # --- generated packages bellow this line ---

  CSApprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CSApprox-2013-07-26";
    src = fetchgit {
      url = "git://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "08g4x6nnd6hkgm2daa5ihhz75pcdx3jzzv8rfjls80qajlhx5rf6";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2015-06-22";
    src = fetchgit {
      url = "git://github.com/chrisbra/CheckAttach";
      rev = "a1d86be7e69b25b41ce1a7fe2d2844330f783b68";
      sha256 = "0scshz5vc5j2lhjj5is4y392xarwsdh4z3y7kyibq3d7fmszksgn";
    };
    dependencies = [];

  };

  Gist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2016-10-10";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "f0d63579eab7548cf12f979dc52ef5a370ecbe63";
      sha256 = "06nix49j4inxy3rkcv32f4ka89g4crqwfqnrm3b76iwwky8m2p17";
    };
    dependencies = [];

  };

  Hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2015-12-24";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "a5db36f048ac16ab9774fc86f36cd4ae9a444932";
      sha256 = "1855n6dsimbc0brfbmmkx1gszhmgfghm1h1mpi95mq9qzbwkgjri";
    };
    dependencies = [];

  };

  Solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  Supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2016-01-03";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "66511772a430a5eaad7f7d03dbb02e8f33c4a641";
      sha256 = "1kxxgplsc40wyl7yj3dpcjjgysd41cd32ppcpnj5knphpjw7abp4";
    };
    dependencies = [];

  };

  Syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2016-10-30";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "734fde7f0b84ff3f670ab5772ed1b8b0c8c16770";
      sha256 = "18nw0zw8h537d189n0z244fllbyyb9fw47brnmsw82w90b771723";
    };
    dependencies = [];

  };

  Tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2016-05-04";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "185jpisk9hamcwb6aiavdzjdbbigzdra8f4mgs98r9cm9j448xkz";
    };
    dependencies = [];

  };

  Tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2016-11-07";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "01f57ac5643b0365021ab891f78519d849867a5e";
      sha256 = "0k0006r895m19kpwqy1ibiia5qm47v4h3mgrlr349wlzqibhmws1";
    };
    dependencies = [];

  };

  The_NERD_Commenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2016-10-10";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "97cb982f1f0d0631b34b71b065e162916bee4036";
      sha256 = "136nirs1zi0pjz06yyw2q72ypwmmj25fkl9fjaqgc5q472d77d0v";
    };
    dependencies = [];

  };

  The_NERD_tree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2016-10-21";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "eee431dbd44111c858c6d33ffd366cae1f17f8b3";
      sha256 = "1fyz3fp2v77piydadcg47pbb7dds9b015kj1baqaxr4gn2gfwq7f";
    };
    dependencies = [];

  };

  UltiSnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2016-10-24";
    src = fetchgit {
      url = "git://github.com/SirVer/ultisnips";
      rev = "71c39721de9cb2d67478e8b8c1a543e006fb67df";
      sha256 = "13lm1fb007ny70pxsvc5wf9s0n90lvimya1n2nn2pyxsnwm416fw";
    };
    dependencies = [];

  };

  VimOutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2016-07-22";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "bd80cee8d9df9530c730ec4237de7ebe197b3642";
      sha256 = "0ynf60vzahif8ccb50kssjk64bh3r8bai3x37n6qb1gi5m61yn3z";
    };
    dependencies = [];

  };

  WebAPI = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2016-07-06";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "e3fa93f29a3a0754204002775e140d8a9acfd7fd";
      sha256 = "0z6s3cnipcww4q33d4dcp0p8jw29izghcrj75fxy6dmy1yw2fbcr";
    };
    dependencies = [];

  };

  YankRing = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=23487";
      name = "yankring_190.zip";
      sha256 = "0nnxpsfjp2p9jvs3y5ynnd5s56snz9927zdp9bgmay2jgxfmp0si";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };

    sourceRoot = ".";
  };

  commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2016-03-10";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "73e0d9a9d1f51b6cc9dc965f62669194ae851cb1";
      sha256 = "1z409hpdk22v2ccx2y3sgcjf4fmnq7pyjfnk72srpqydfivxsl13";
    };
    dependencies = [];

  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2016-09-02";
    src = fetchgit {
      url = "git://github.com/FelikZ/ctrlp-py-matcher";
      rev = "3624f3a085681f787f1f9b7a8a24d4bed395acf1";
      sha256 = "1126gphnhfvba5xzvqj4s582k61xsvi5hn86zag42v14v5csgw9d";
    };
    dependencies = [];

  };

  ctrlp-cmatcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-cmatcher-2015-10-15";
    src = fetchgit {
      url = "git://github.com/JazzCore/ctrlp-cmatcher";
      rev = "6c36334f106b6fd981d23e724e9a618734cab43a";
      sha256 = "1573kd6xf3n8sxlz2j4zadai4rnc7k3s9c54648yfzickwn57d8q";
    };
    dependencies = [];
    buildInputs = [ python ];
    buildPhase = ''
      patchShebangs .
      ./install.sh
    '';
  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "git://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-09-22";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "0c89i0spvdm9vi65q15qcmsfmwa9rds2wmaq1kf6s7q7ywvs6w8i";
    };
    dependencies = [];

  };

  fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2016-11-05";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "b3a8be6975dcc27b523b030bf5d35d9c737aef18";
      sha256 = "1qizj0xmpaj32b9f8p2d76s5rsvm8cxv0rh5yiczlgfvflbi587r";
    };
    dependencies = [];

  };

  ghcmod = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2016-06-19";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "1d192d13d68ab59f9f46497a0909bf24a7b7dfff";
      sha256 = "0bzahgzagnf0a9zv86jhdf8nc3p0yfz9izv5n3lc8gc12cp47d0a";
    };
    dependencies = [];

  };

  vim-auto-save = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-auto-save-2016-09-12";
    src = fetchgit {
      url = "git://github.com/907th/vim-auto-save";
      rev = "28300c8a7b8cea137c065a48fd9bcc2348f08707";
      sha256 = "0n3xbp8vf3xsh6y6f855q313scldqm9593bhxydyszy1parvxwb5";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2016-11-02";
    src = fetchgit {
      url = "git://github.com/Chiel92/vim-autoformat";
      rev = "15ee797ad37093e9841b41c121c8d93cf1dedf93";
      sha256 = "10alg9a8mhasqp26mg7xlran1x474ip3k03s2sjhlvizy6mv5rba";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2016-11-02";
    src = fetchgit {
      url = "git://github.com/LnL7/vim-nix";
      rev = "b06cccd8ff61149b13d3fc8b7e0d06caa55c9888";
      sha256 = "0d1wxxijyyl449f81asl9d31kg0wvs3m0fypin172ahgpf3lyar4";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2016-11-04";
    src = fetchgit {
      url = "git://github.com/Shougo/deoplete.nvim";
      rev = "5fc5ed772de138439322d728b103a7cb225cbf82";
      sha256 = "1nn9k9rk6m3x48mm6mlji374vkrgwz1rf3pp8smd1hj30dy0njfk";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2016-10-30";
    src = fetchgit {
      url = "git://github.com/ajh17/Spacegray.vim";
      rev = "79936a4434bf57b64c2d73320e62b4e67d84af74";
      sha256 = "0dg037aw99yjdirw6f8v6da1lyf5ba2c6bni2wnka6bmzqx0k53r";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2016-07-19";
    src = fetchgit {
      url = "git://github.com/alvan/vim-closetag";
      rev = "e7e6cb99b9abb2aaa4711b9b2a98ad029169253b";
      sha256 = "0827yrgawfjf82z37lndf58ikyh6s8g9qhxvnbfxvz8cc4a6r21v";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2016-10-11";
    src = fetchgit {
      url = "git://github.com/ap/vim-css-color";
      rev = "27903efc1b5330230d5c8c336c26ac7a8ac2e5dc";
      sha256 = "0kr9xf2y001d42x7fam50qbd09fb3rr374qv8m2p5z2d9c21par1";
    };
    dependencies = [];

  };

  clighter8 = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clighter8-2016-11-08";
    src = fetchgit {
      url = "git://github.com/bbchung/clighter8";
      rev = "a264494b6dd3e7636fa31b8aee9b3a42a635a69f";
      sha256 = "1dg22yfr0za7milqzm7xywa6j9dfs2kvkjlwa046jjkjaqzlfx48";
    };
    dependencies = [];
    preFixup = ''
      sed "/^let g:clighter8_libclang_path/s|')$|${llvmPackages.clang.cc}/lib/libclang.so')|" \
        -i "$out"/share/vim-plugins/clighter8/plugin/clighter8.vim
    '';
  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2016-11-04";
    src = fetchgit {
      url = "git://github.com/benekastah/neomake";
      rev = "0c8795de4519600c204227fdf86c83ca499db783";
      sha256 = "0vif3jxrxpq8imnhbkl82fb7vvfi4illxxm6drl6wd5wijfwq39k";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2012-12-29";
    src = fetchgit {
      url = "git://github.com/bitc/vim-hdevtools";
      rev = "474947c52ff9c93dd36f3c49de90bd9a78f0baa1";
      sha256 = "1wwjb9m2l9q75d408jzq9bwv5i376bfgs6vc3ihwwlawcrmhjpxz";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2016-09-03";
    src = fetchgit {
      url = "git://github.com/christoomey/vim-tmux-navigator";
      rev = "e79d4c0c24c43d3ada283b1f5a1b8fa6cf820a70";
      sha256 = "1p4kb8ja86pa3l9jh8yfjvdvdik4fwnpbpl34npjwbga52pawn65";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2016-10-25";
    src = fetchgit {
      url = "git://github.com/ctjhoa/spacevim";
      rev = "51d936482ce0710f6211aefca45cd33ab59d8444";
      sha256 = "156sc8ynj1mg75i7n3dpm5nqlwcw727m41jw32fm3pahr3yq3ydq";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2016-11-07";
    src = fetchgit {
      url = "git://github.com/ctrlpvim/ctrlp.vim";
      rev = "88b61e77a285d10d0163bd383d3bb2909ea2ddca";
      sha256 = "0zb5hcsbgvbsp5h0alkqyqbikzicl29mraw787p2chbps10n1qjw";
    };
    dependencies = [];

  };

  agda-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "agda-vim-2016-10-22";
    src = fetchgit {
      url = "git://github.com/derekelkins/agda-vim";
      rev = "5c698a0dcc4881ea8fbe672e60aaca70d4c8b6f4";
      sha256 = "0ii9gmwnc97zjis7d0a230gbh4pqvx4ja83aypmpmy67s3sxhwvf";
    };
    dependencies = [];

  };

  dracula = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "dracula-2016-09-21";
    src = fetchgit {
      url = "git://github.com/dracula/vim";
      rev = "926dfbab01128322f6326bdd10de2856b1fa3232";
      sha256 = "1kqd367qa2dnz3qf10lyw7hacahylc94axc6f6f5nw4cklm1g8yv";
    };
    dependencies = [];
  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2016-10-31";
    src = fetchgit {
      url = "git://github.com/digitaltoad/vim-jade";
      rev = "cc1bddc890f4856aa0511fdfd7c55d2e66f688b5";
      sha256 = "1d5rbaslvr14lcdffrxp0ycsm2nzvq5zyjk0x0nzwhzvvs4fqi40";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2016-07-01";
    src = fetchgit {
      url = "git://github.com/eagletmt/neco-ghc";
      rev = "7f02a9c25fb272a87d2be092826e2cd3094c620d";
      sha256 = "1fcfk45qb96h6y4zb3p0104iyqc85q1synn9ah56zp6hnkkyffbw";
    };
    dependencies = [];

  };

  editorconfig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "editorconfig-vim-2016-07-16";
    src = fetchgit {
      url = "git://github.com/editorconfig/editorconfig-vim";
      rev = "a459b8cfef00100da40fd69c8ae92c4d1e63e1d2";
      sha256 = "03slzk7jgr348f59pxghmd9giwla63lxmwvripg99zrlgl0pvp5g";
    };
    dependencies = [];

  };

  acp = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "acp-2013-02-05";
    src = fetchgit {
      url = "git://github.com/eikenb/acp";
      rev = "5c627cec37d0d3b1670cb250d84e176e8b0c644e";
      sha256 = "0h7s4nvxin7m2caka7g1hhlxj1bbiwsvw8s2lqwlh7nq43v23ghg";
    };
    dependencies = [];

  };

  elm-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "elm-vim-2016-10-02";
    src = fetchgit {
      url = "git://github.com/elmcast/elm-vim";
      rev = "7760aed9f258cf6a7d2c56d547dd3ea45f832025";
      sha256 = "1f1z2929aka2shkwb8z2ky26cvw2cgx7wdcikw9mljpgc1s7nl5d";
    };
    dependencies = [];

  };

  vim-localvimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-localvimrc-2016-10-07";
    src = fetchgit {
      url = "git://github.com/embear/vim-localvimrc";
      rev = "f0c9b8d0b6f0d4c83d9dba5137772bd6c97afb4e";
      sha256 = "02dzh8gckbpdifh7nmfzwn6qs3swjm783ld4h7dl1ky6xq4f06mv";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "git://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "git://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2016-10-23";
    src = fetchgit {
      url = "git://github.com/fatih/vim-go";
      rev = "10c805b83f160eb9e7f9cbe00d26c1b6d06ba636";
      sha256 = "0316kzmwb2p91rwz31ddr7r5bd52aa7jxzkb3vdhdb7f3bmcwx3q";
    };
    dependencies = [];

  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2016-08-01";
    src = fetchgit {
      url = "git://github.com/flazz/vim-colorschemes";
      rev = "b8dff40f69f1873effbed97c759a8452ecb240ed";
      sha256 = "1mb08l2crl5mal0jllh9s099w2bqcb88vfjw3z5zj1jn8bbpniaj";
    };
    dependencies = [];

  };

  floobits-neovim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "floobits-neovim-2016-10-07";
    src = fetchgit {
      url = "git://github.com/floobits/floobits-neovim";
      rev = "85d3493d05ac1d7f5606d40fbe619df16af917bc";
      sha256 = "16c12dgk60mmhyijfk4f33k8i48r1hpjlnxlvdk5kymv7b2xq0fa";
    };
    dependencies = [];

  };

  psc-ide-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "psc-ide-vim-2016-11-05";
    src = fetchgit {
      url = "git://github.com/frigoeu/psc-ide-vim";
      rev = "bb7f0ef6620899cb6256e3ee5956d3b30769488b";
      sha256 = "1x47phq0shap338as120vf0srl69fas11kggzsxjg1dxblg69iww";
    };
    dependencies = [];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2016-10-11";
    src = fetchgit {
      url = "git://github.com/google/vim-jsonnet";
      rev = "bf1997a5607912cc121fe617a6fef76d3d872aa4";
      sha256 = "04vgbzknz7x6r8gwvlajjqd653fvv1x4szib00bnzw87vsagdiiy";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2016-11-06";
    src = fetchgit {
      url = "git://github.com/hecal3/vim-leader-guide";
      rev = "b1dd2667cb74147c06853c39530984fbc629eb48";
      sha256 = "0xacamv3dcnkdh9xclvw76fp20rxgqb1m3068l582c6g5p7lj0yi";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2016-07-29";
    src = fetchgit {
      url = "git://github.com/idris-hackers/idris-vim";
      rev = "7ef7a2ed9135d69a0dea6b571a20ddf2b0bf7a90";
      sha256 = "0py7vyg38yn6bl7pwyyhylpqp14smqjzbfj7rjzjfnlq33v7ysij";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2016-11-06";
    src = fetchgit {
      url = "git://github.com/itchyny/calendar.vim";
      rev = "ca4b4b2ed364831ba27d50f17b44d1e9506715ef";
      sha256 = "1i2ywg0h3rb6f05k7ahng9bvjg7hxqdg1nzcijs5m6kxkn8kjj2k";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2016-11-06";
    src = fetchgit {
      url = "git://github.com/itchyny/lightline.vim";
      rev = "836d4c84f76e7066bcfa4c6c60449714cf2b2c45";
      sha256 = "0qdhpwr4iyifmk0l463s4k5nm8k744ycvxmxgz3s38vkn8q5y06w";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2016-09-06";
    src = fetchgit {
      url = "git://github.com/itchyny/thumbnail.vim";
      rev = "d697fb7a73a53275390c20040faab87b54f12f84";
      sha256 = "112hkblw30ym7bpv8454fylalv9kn0l3268gpkh9a5qdr2kf99b1";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "git://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "10wpfvfs8yv1bvzra4d5zy5glp62gbalpayxx7mkalhr2ccppy3x";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "git://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2016-11-03";
    src = fetchgit {
      url = "git://github.com/jceb/vim-orgmode";
      rev = "304fd3ced3b929a8507e460b99b0bf4e6a9b3c7d";
      sha256 = "13r4mnqng5hsiarqdrr3vqa4frf6jlwlaxpl72czvpyrvd4mvc2m";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2016-10-19";
    src = fetchgit {
      url = "git://github.com/jeetsukumaran/vim-buffergator";
      rev = "c07d16dd3df10bbb5adc3e9b009e341bfa1f673e";
      sha256 = "0bj70lkqizfzmaxwrxcqv1151kx37v2v57aaqy4vcnfn04wq3h95";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2016-06-14";
    src = fetchgit {
      url = "git://github.com/jgdavey/tslime.vim";
      rev = "c980c76bbfc9a523fcf1edf08580d0d3a486e8f2";
      sha256 = "0gifyxwlspfnkni886adwn9kc0dckanjk0097y8pwxh7qbwfydf1";
    };
    dependencies = [];

  };

  auto-pairs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "auto-pairs-2016-07-17";
    src = fetchgit {
      url = "git://github.com/jiangmiao/auto-pairs";
      rev = "1b3a1efb078fdf74d4013308b63de57dfda0cc8e";
      sha256 = "1g5gb9xvc9xw3rxg8p4w3qcsdl3xfpi5ax380916aq237kmrnzdk";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2016-09-19";
    src = fetchgit {
      url = "git://github.com/jistr/vim-nerdtree-tabs";
      rev = "5a91230193fea7f9c8d792cb5c635998d868337d";
      sha256 = "08g587bnd8n61nj44ghjadwqpbbqya4hig56afna6rhs341zwlpm";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2015-09-18";
    src = fetchgit {
      url = "git://github.com/jnurmine/zenburn";
      rev = "f7847fb1531b91e2b4bb4aed5db3146f07765179";
      sha256 = "1las12jznf25dkxrjk3s9l70c6wnpjisngmvi83bhw5gvx4c7mq5";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "git://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "git://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2016-10-29";
    src = fetchgit {
      url = "git://github.com/junegunn/fzf.vim";
      rev = "0bc9b231fbab6749f18f2f34cc21c649b9a7d3ed";
      sha256 = "1gpy744qd7hch1ab7kfzz1njg74hasvh53w7kbm7ni5sw7pn5w64";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-06-24";
    src = fetchgit {
      url = "git://github.com/junegunn/limelight.vim";
      rev = "106fb5749d227a0de72e36068ed72798c6fd48e6";
      sha256 = "0fp4yp50n5v5zx3a7afh9wip4nwcfhmdgdzwpnl79jvild1z9fgh";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2016-08-05";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-peekaboo";
      rev = "9c8415c022ab24ce51af13aa43255d5a7c7ef670";
      sha256 = "10c8j4wcg7g3i3vyvlcc21j0a3xmbl5ii5fl5k27iy2icf5rm018";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2015-11-02";
    src = fetchgit {
      url = "git://github.com/justincampbell/vim-eighties";
      rev = "62a9719df45fddd0456bf47420fc4768f9c8f5a5";
      sha256 = "1ada7f2lhdwjqmy5kxma69s215z4phi4khh8hsy5qd6k3a4bvyrs";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "git://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "1z4mdy47cpwcdhvy8mr72vhlybxn1y59yd3ixf6ids1bzpkrd7zl";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2016-05-20";
    src = fetchgit {
      url = "git://github.com/lepture/vim-jinja";
      rev = "0bcc2993ef13bacd4bf1a0d91eb17652f7aedb86";
      sha256 = "1wypg9rf7q65g6l3ajp75gdb4cd7spckzd4b7ccg8c47vd937dcj";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2016-11-04";
    src = fetchgit {
      url = "git://github.com/lervag/vimtex";
      rev = "fa1adca64aea62d512bbc9e0b0f4b88ac8667ed4";
      sha256 = "0gnz4jh5gagnk06jndmxqmjhymbnpjz18wx5i071q7imkv0420s4";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2016-10-19";
    src = fetchgit {
      url = "git://github.com/lokaltog/vim-easymotion";
      rev = "11632455de8caa40f264501df8f0a3e249cf0595";
      sha256 = "1lmmahpsghfqnri7wi2i9370q4dfzpdbafabi97vfxyyclxj4bz9";
    };
    dependencies = [];

  };

  rainbow = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow-2016-10-28";
    src = fetchgit {
      url = "git://github.com/luochen1990/rainbow";
      rev = "906094f73a46ab4636806541b50c5d4182fa09e1";
      sha256 = "1za2pwv24yiap2655wagyg4yd69g1xqwayazablwj7x1wvqdvd5p";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2016-01-31";
    src = fetchgit {
      url = "git://github.com/lyokha/vim-xkbswitch";
      rev = "89fa3fc16251f2e97281d29ade3ee022ba285003";
      sha256 = "16wahaz9d6jyqlvmsn764xqircrwaap3pn4fbgmly7vfmdvq4p8b";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2016-10-31";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-startify";
      rev = "9732427469c6933cbedeb7e662c70a2aaf4e63d2";
      sha256 = "022ibyqq140130x8c2901sskh03q516ghnc25i41qv6b2hcsq1ad";
    };
    dependencies = [];

  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2016-10-12";
    src = fetchgit {
      url = "git://github.com/mkasa/lushtags";
      rev = "ef6410cd66c6729e6f4795222bdc0e406251f27a";
      sha256 = "094cl57zfqjq7gpv4151zxipb6kd1czwx4nv6x8wsl3n0z4p3jkx";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "git://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-indent-guides = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-guides-2016-04-17";
    src = fetchgit {
      url = "git://github.com/nathanaelkane/vim-indent-guides";
      rev = "018298ead9d3aa9cd3b4ae222f81022a33978b09";
      sha256 = "0zyrs9r3vza2kqhqir6qpkygy6yljpn877bvycspv89ljzczmwrs";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "git://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2016-11-05";
    src = fetchgit {
      url = "git://github.com/neovimhaskell/haskell-vim";
      rev = "cf2f339d2b551547d4f5a365db17f0f12b99a0c0";
      sha256 = "1zdq7rc7bklz88df2cwgw7n43z0mn4fylx7gyfmi8sfm1bx5avnj";
    };
    dependencies = [];

  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2016-07-19";
    src = fetchgit {
      url = "git://github.com/osyo-manga/shabadou.vim";
      rev = "7d4bfed1ea8985ae125df3d1403cc19e252443e1";
      sha256 = "1kvik1yf7yjg9jdmdw38yhkksxg0n3nry02banwik7wgjnpvg870";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2016-09-05";
    src = fetchgit {
      url = "git://github.com/osyo-manga/vim-watchdogs";
      rev = "96ee0ce968da8da8ace48457665c7d5c942dd49d";
      sha256 = "16dk0wsikqmcywgm04vwv76p2sc6jw0krq4cg02zdpgyb4xxgp3n";
    };
    dependencies = [];

  };

  vim-markdown = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-markdown-2016-05-19";
    src = fetchgit {
      url = "git://github.com/plasticboy/vim-markdown";
      rev = "a3169545f330ec8080244c3ad755bb2211eca8a0";
      sha256 = "1ycqx280xpc5gvfx8rrnmkqlv8q8g51hgiryx6yvd9a8ci805cx1";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2016-10-18";
    src = fetchgit {
      url = "git://github.com/racer-rust/vim-racer";
      rev = "6c87080bdb145595e37c304fd8b570b349eda381";
      sha256 = "1hjf8j7jnf2vb62w6zv3xm0hdhjmm0hxqq18symxfqpkii1kwx6c";
    };
    dependencies = [];

  };

  purescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "purescript-vim-2016-08-31";
    src = fetchgit {
      url = "git://github.com/raichoo/purescript-vim";
      rev = "2c55bcefd63bc40ed2aa9d6ce9d89a590dfa3477";
      sha256 = "1y96w8p865gd6zr29wpxn1qwsk833y06x1qp586gylgi0jp1ybzv";
    };
    dependencies = [];

  };

  vim-grammarous = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-grammarous-2016-10-07";
    src = fetchgit {
      url = "git://github.com/rhysd/vim-grammarous";
      rev = "81ff81d1ac5e2ea059600588165ba9b2ecb854eb";
      sha256 = "1xpm1j64f5c62d7dnpkc9lfg6qh0nwjbnk3a5gqmz3iy4z1hsdwb";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2016-10-28";
    src = fetchgit {
      url = "git://github.com/rust-lang/rust.vim";
      rev = "59e5e2f8b7df21eb438124b95c7295da9c53e1d7";
      sha256 = "1zdx29l6lhini9562j75g3d41yvjf78pi8cady16i7644hw11r0m";
    };
    dependencies = [];

  };

  neoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoformat-2016-11-05";
    src = fetchgit {
      url = "git://github.com/sbdchd/neoformat";
      rev = "8a4d9783879e404bd0a9e185dfec2cd6cd529c31";
      sha256 = "076cm2cg4kyps7n5d3kp2vjcwvkay20f1pl26yvdsjac14w6x9l9";
    };
    dependencies = [];

  };

  vim-polyglot = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-polyglot-2016-09-11";
    src = fetchgit {
      url = "git://github.com/sheerun/vim-polyglot";
      rev = "74652b465d7eff97070001317a4ea5557717378d";
      sha256 = "18bw8fdpq5riqfy656kw4a9hmrk8s967qx36lq0s16sbyqxm15ag";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2016-10-19";
    src = fetchgit {
      url = "git://github.com/shougo/neocomplete.vim";
      rev = "4bf7526a1c8cca9f8614e8a09178f334eaca0481";
      sha256 = "1qpxqvdiglisl8bnh1wli957lwr56mq96pm266qmwj6d38h8yby7";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2016-11-05";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet-snippets";
      rev = "4431bf176650696d5a8dd93814812afd0d06212c";
      sha256 = "0fbwzlvdbrmia97pyzgyffbqrimp2dxjn6cc45ia1kqgnhwdk4pd";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2016-11-04";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet.vim";
      rev = "22bf9611263fcc9fd2c4bd61031053624ff82714";
      sha256 = "0f0j0spw8zkvrfhbdlk020y19fh4awhhqwc3ylnxday3q5avxa16";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2016-11-04";
    src = fetchgit {
      url = "git://github.com/shougo/unite.vim";
      rev = "f3f6df24c04faf29ae4d716aa776f85e88e7ea38";
      sha256 = "1yyw1blg82g6d8dbl6f4kgfka3d5lh0vgjmp310aysqdhnfag2az";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2016-08-06";
    src = fetchgit {
      url = "git://github.com/shougo/vimproc.vim";
      rev = "25cb83f24edec4aec1e9f1329302235e7a7a7fe0";
      sha256 = "19nl21623cv05j6ljyn35qm38pw3680nch2by1gapqmxazp99i20";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2016-10-20";
    src = fetchgit {
      url = "git://github.com/shougo/vimshell.vim";
      rev = "b42ba02a491d6a4b6daa3178a747e59e7b1800c7";
      sha256 = "1vpxyfyc9p8h5pwmkdqfvvyxgddbzbmycnzpn9kbyxz89r8k94kj";
    };
    dependencies = [ "vimproc-vim" ];
  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2016-01-19";
    src = fetchgit {
      url = "git://github.com/sjl/gundo.vim";
      rev = "e7fe41024ace9047eee610f23311d44fd9d917c0";
      sha256 = "14mx617mxh7q6rhjfcnv080hpr965vhqzfwhlizpmzc16lsf7ni1";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2016-07-05";
    src = fetchgit {
      url = "git://github.com/takac/vim-hardtime";
      rev = "93ed99803df721648a9b93f0ccd4afe3d8d95a4e";
      sha256 = "0as6kbdg2jqkxphxyv6ik6qxyp245hl52aqmx5gjd4vi3pryg0gl";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "git://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2016-03-07";
    src = fetchgit {
      url = "git://github.com/tex/vimpreviewpandoc";
      rev = "b109d41ad6478df5ec7f1311950c6efca66f36e4";
      sha256 = "1gx326xarjs3qjygpkrknncad90crjqfx8v6pir4r7k1hl7dfxc4";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2016-10-16";
    src = fetchgit {
      url = "git://github.com/thinca/vim-quickrun";
      rev = "c4c368c835b91c012b011dde613a914c0e167fd0";
      sha256 = "0hk7y7gkcxkzgp102x2b3igx7pq194h6ixahmv8s9qv5ndv2km4s";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "git://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2016-09-07";
    src = fetchgit {
      url = "git://github.com/tpope/vim-eunuch";
      rev = "7eeb681ff3caedc1c01e50966bc293951f7b3e21";
      sha256 = "0hk4p1qjmplddmwrpp6b2x776z1298pkcgp855kgigib53w5srmc";
    };
    dependencies = [];

  };

  vim-repeat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-repeat-2015-05-09";
    src = fetchgit {
      url = "git://github.com/tpope/vim-repeat";
      rev = "7a6675f092842c8f81e71d5345bd7cdbf3759415";
      sha256 = "0p8g5y3vyl1765lj1r8jpc06l465f9bagivq6k8ndajbg049brl7";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "git://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "09998lnfcshqis5m062wlag6y476imq9jday9gp4ayjjl1cp3cwx";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2014-10-28";
    src = fetchgit {
      url = "git://github.com/twinside/vim-haskellconceal";
      rev = "f73c5dd660b7009a050b131783d7c17b4954e4d9";
      sha256 = "1a1v0m3qj0gian3mp5xynf2ghscr3xaid37b0wi38bb4f2qrigqy";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2016-11-04";
    src = fetchgit {
      url = "git://github.com/valloric/youcompleteme";
      rev = "4f2494e87ebd5a6e9b5dc10a436d4d943f137fe6";
      sha256 = "03fl5ccql6v6da27wns0fiqcyhn0rmwx5vz7l3xqq1xg3x44m5n2";
    };
    dependencies = [];
    buildInputs = [
      python go cmake
      (if stdenv.isDarwin then llvmPackages.clang else llvmPackages.clang-unwrapped)
      llvmPackages.llvm
    ] ++ stdenv.lib.optional stdenv.isDarwin Cocoa;

    propagatedBuildInputs = stdenv.lib.optional (!stdenv.isDarwin) rustracerd;

    patches = [
      ./patches/youcompleteme/1-top-cmake.patch
      ./patches/youcompleteme/2-ycm-cmake.patch
    ];

    buildPhase = ''
      patchShebangs .
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      mkdir build
      pushd build
      cmake -G "Unix Makefiles" . ../third_party/ycmd/cpp -DPYTHON_LIBRARIES:PATH=${python}/lib/libpython2.7.so -DPYTHON_INCLUDE_DIR:PATH=${python}/include/python2.7 -DUSE_CLANG_COMPLETER=ON -DUSE_SYSTEM_LIBCLANG=ON
      make ycm_core -j''${NIX_BUILD_CORES} -l''${NIX_BUILD_CORES}}
      ${python}/bin/python ../third_party/ycmd/build.py --gocode-completer --clang-completer --system-libclang
      popd
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = http://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2016-10-26";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline-themes";
      rev = "e03e9f62d25f9afb04c88ec6ca66cf2098242016";
      sha256 = "0c6qnh7xjp7qiw5hdz4a3n9v4fk7vynm592aqs4cmhhgjfv1s845";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2016-11-05";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc";
      rev = "a92155e8d3a5d8d4e4636783bdebb72ab465b89a";
      sha256 = "0f4mf40h9h55nishgml833mj1n99wpxbahzgmmx3avfvhxcr97hm";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2015-06-01";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-after";
      rev = "4377665e5c98f29ea838deb3b942200b8dd096ef";
      sha256 = "1379g174pvsaw1wdv1n18gby84sv59rsamfcgq9bqd4kg54g6h3j";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2016-11-05";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "c76442ccbdd7889184683dc1d39c16c612c2c19f";
      sha256 = "1ad60ls4xrbf01sjprksrx2j9x2y4m6gd7hq3p9ygrcmcxw64khm";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "git://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  Rename = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Rename-2011-08-30";
    src = fetchgit {
      url = "git://github.com/vim-scripts/Rename";
      rev = "b240f28d2ede65fa77cd99fe045efe79202f7a34";
      sha256 = "1d1myg4zyc281zcc1ba9idbgcgxndb4a0jwqr4yqxhhzdgszw46r";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "git://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "git://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2016-11-01";
    src = fetchgit {
      url = "git://github.com/wakatime/vim-wakatime";
      rev = "5fb34105de863ca90f3f8568b85fa017a42568af";
      sha256 = "1flsdmf60fp8z0k080qfzdcpcb761zrj5qa3np2y9w24wbff9m5p";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2016-10-27";
    src = fetchgit {
      url = "git://github.com/wincent/command-t";
      rev = "d2467c84af8a1f1a2d0366127550d0a241dd2548";
      sha256 = "1r81a0wlj9aqx0s11h6ddkdwbahxbg1l425jdyrwvxwd973nwkj6";
    };
    dependencies = [];
    buildInputs = [ perl ruby ];
    buildPhase = ''
      pushd ruby/command-t
      ruby extconf.rb
      make
      popd
    '';
  };

  vim-easytags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easytags-2015-07-01";
    src = fetchgit {
      url = "git://github.com/xolox/vim-easytags";
      rev = "72a8753b5d0a951e547c51b13633f680a95b5483";
      sha256 = "0i8ha1fa5d860b1mi0xp8kwsgb0b9vbzcg1bldzv6s5xd9yyi12i";
    };
    dependencies = ["vim-misc"];

  };

  deoplete-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-go-2016-11-12";
    src = fetchgit {
      url = "git://github.com/zchee/deoplete-go";
      rev = "807b5536e7cebd06d0ce7b7d54c021a82774aee2";
      sha256 = "1ragxnlzpf17f1wdy512hkz6bd673gzl16f14v78873rcyxpiw53";
    };
    dependencies = [];
    buildInputs = [ python3 ]; 
    buildPhase = ''
      pushd ./rplugin/python3/deoplete/ujson
      python3 setup.py build --build-base=$PWD/build --build-lib=$PWD/build
      popd
      find ./rplugin/ -name "ujson*.so" -exec mv -v {} ./rplugin/python3/ \;
    '';
  };

  deoplete-jedi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-jedi-2016-10-22";
    src = fetchgit {
      url = "git://github.com/zchee/deoplete-jedi";
      rev = "57e5b61578d4d0a27fa75fd5f8dc21d110d60989";
      sha256 = "050ck7k37lbvw44z7hdk530cswcqywrdfvw5v1bs37mjnh3l9dnj";
    };
    dependencies = [];

  };

  goyo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-2016-04-03";
    src = fetchgit {
      url = "git://github.com/junegunn/goyo.vim";
      rev = "8e8f1d45b61e1fce7f84ee061c38f9e033e86ff9";
      sha256 = "120farhbfyzd7k1s1i68drwa5zzzm9yrcwzw45gwa2j7kqbv4hnx";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

    unpackPhase = ''
      (
       sourceRoot=d
       mkdir $sourceRoot; cd $sourceRoot;
       unzip $src
      )
    '';
  };

  pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2016-10-13";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "7ba2e1b67a8f8bcbafedaf6763580390dfd93436";
      sha256 = "1g15wzyw9b93n3icwpscx4b4qkn23snbmqjqp867ba0w0z3h6hpv";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  rainbow_parentheses = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2016-09-05";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "4b7535921819a5b2e39be68f81109ea684232503";
      sha256 = "0ghds721dawm8mcd8cp23hfqpgiznh811z73zxlqrm1sg2fmdq1s";
    };
    dependencies = [];

  };

  sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sleuth-2016-11-06";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sleuth";
      rev = "62c4f261874dd44e6cdc6788b4a6bc59f9dfe746";
      sha256 = "13w4gv2k91ahdc25vhi0ilqphlnix1q5gddcihi8k7fapx990a9k";
    };
    dependencies = [];

  };

  snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2016-09-01";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "31986191ac9923afcd53bf6425c9b6c35fdbb214";
      sha256 = "1l48h5xmkx412bm29mvl6kz11n7xbkk37ph8v5vgdws380d0fiag";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  sourcemap = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2016-06-01";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "e49d6c2459e0f5569ff2d533b4df995dd7f98313";
      sha256 = "1v0q2f1n8ngbja3wpjvqp2jh89pb5ij731qmm18k41nhgz6hhm46";
    };
    dependencies = [];

  };

  table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2016-09-28";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "441c30c35aec9d5c2de1d58a77a7d22aa8d93b06";
      sha256 = "04fdd2hgrcrgqqflzlvv7j9c53m8f2divi075p75g6grkxxyninv";
    };
    dependencies = [];

  };

  taglist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=273";
    };

    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
  };

  tlib = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2016-08-07";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "8c74564396e368788a5cb901b0e8017a3166cee9";
      sha256 = "15bh6q8g7p1giz2lybqhdf7a7xisqwpr751gprqx3vmh97drry5z";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2016-07-19";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "17dfeb6aeacc40036567d29c691898ac57b09182";
      sha256 = "0xmc95h5nbmjx6hvfd9lvkz8hdp8fw5xm5c7wcyy5f0rg7b6l68x";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2014-09-22";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "a5d20500fb8812958540cf17862bd73e7af64936";
      sha256 = "1wfkwr89sn2w97i94d0dqylcg9mr6pirjadi0a4l492nfnsh99bc";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2016-07-12";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "b14414215b394a0ef887ea301085ae4b80012e38";
      sha256 = "1gr0rjn1vwqv4p51yb0s65gnpy1r0533lfy5nqbg20j4687yxls5";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "0csy68x686l3x5ancidxb5b6prg9k7ikybqzq3klx0gs5rmksfy4";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0alak8h33vada2ckb0v06y82qlib5mhyc2yswlv1rqh8ypzhq3mc";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1ld059y2qwlc5bdfjm2p314s1qh31lxs54g944pw49r46s5nlslr";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1ksm2b0j80zn8sz2y227bpcx4jsv76lwgr2gpgy2drlyqhn2vlv0";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2016-02-07";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "872f9302cf0eb8e9cb6259ea4f329d2265f9e32d";
      sha256 = "14aixpj9p8b568mdh4pl7bmpw1rsc4d7axqr09g1m0a8q6rxipc7";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "147s1k4n45d3x281vj35l26sv4waxjlpqdn83z3k9n51556h1d45";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2015-03-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "2aed79ba5d8c5e6abd102de77e55e242f61b17f1";
      sha256 = "0zx1q9994py6jmm0qbbx6fc1dy5la8zfskkbvqqxssxrl5dx7vvi";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "0cjz7mlyfkkncas4ss7rwxb0q38ls1qw1p15hac1imscscsvyjc6";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "0i4gfp30hmw1vqjl6zxjrgkca3ikdkcnjmma2mncjmcr6f59kjzy";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2014-01-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "05b8a0c211f1ae4c515c64e91dec555cdf20d90b";
      sha256 = "15l2201jkfml08znvkkpy7fm3wn87n91zgd9ysrf5h73amjx9y2w";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2013-07-12";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "8eb7217e636ca717d4de5cd03cc0180c5b66ae77";
      sha256 = "0gcvb922w4jsi203ygbnij9xhmgc6knj9b3ivw3m0fv5ckk4iw5f";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "1xq38kfdm36c34ln66znw841q797w5gm8bpq1x64bsf2h6n3ml03";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1i64ppdfp2qqq7vw1jf160mj4ikc04v39iazdab83xmiqjsh8ixw";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2016-11-04";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline";
      rev = "258430db82329c1298750af91391c1b21a5a5b58";
      sha256 = "16m884mfrhmnn12nclmdngkcknkhy1kcn4dhpkk7fs5i89yik1rj";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2016-09-19";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "b91dbe92ad794a85a03b089f384fa324ff4e0c3d";
      sha256 = "0rkv0n9r3rczx1269i9nf4xs3q934n7iqnrykhnlqbl255s5agd4";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2016-03-06";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "0cb6b98fc155717b0a56c110551ac57d1d951ddb";
      sha256 = "10j1fz7si7xqqs4p7h66jd0xzr116cv3xjyac9p20fc0yyyg1wbh";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2016-09-21";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "8f27e74bd1f8edb3ca5711864b34cb4c526d9947";
      sha256 = "0zymx6ww6yc9h06k373z7mbv07jmi66zv1cm15ip2qnik1nr80p7";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2016-10-27";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "1742a8f568df549f4daeda90174b54d0c371501f";
      sha256 = "1d4d4lpf43dd5fpn3cqb3lrfr4k6ilmanmk9cymwf9byri3s4xdv";
    };
    dependencies = [];

  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2016-03-16";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "99501642c1dd3f703ac6301ae13469f4990b7a06";
      sha256 = "0dkm3v1jqi8aq0jfpa6fdwgbfbwidc32ci1y9vhqb1prs15qrqfl";
    };
    dependencies = [];

  };

  vim-misc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-misc-2015-05-21";
    src = fetchgit {
      url = "git://github.com/xolox/vim-misc";
      rev = "3e6b8fb6f03f13434543ce1f5d24f6a5d3f34f0b";
      sha256 = "0rd9788dyfc58py50xbiaz5j7nphyvf3rpp3yal7yq2dhf0awwfi";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2016-06-03";
    src = fetchgit {
      url = "git://github.com/terryma/vim-multiple-cursors";
      rev = "51d0717f63cc231f11b4b63ee5b611f589dce1b3";
      sha256 = "1s06wp4cjdmfvljzd9gz0wawkfcpkj8l2scjdx626ml740pnhmx8";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2016-10-17";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "f1f7108aacac5dc3a7e3b697c489f8271fa054b8";
      sha256 = "0y9ls3m9l2f5jwkbfn26xhw1brp03c9ylmzxfnw28z2bfh5778iy";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2016-10-07";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-signify";
      rev = "a7e3219de8f603aaec35b30027778aa417fcb691";
      sha256 = "1dq369s2bavwkv59cklbjz2zr6vk5ahqs53x1pj0l1xx3rg9h3aq";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2016-11-05";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "93c3241c79886d027c802c93804e597f5b9d742f";
      sha256 = "0m0k2czyhf9lwla4pyzf6jrb0h1xclcww1pqwnmbf1g10ns7n2zh";
    };
    dependencies = [];

  };

  vim-webdevicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-webdevicons-2016-11-06";
    src = fetchgit {
      url = "git://github.com/ryanoasis/vim-devicons";
      rev = "4fbf39a8984ed9a450b5cd078d65955de472bace";
      sha256 = "0m549vm5qzk1hiixf4p740fkqw58y46pdimb5jhpm484sqyggvj5";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "18lqrl3hqb6cmizc04bbnsh8j0g761w2q8wascbzzfw80dmxy36b";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2016-05-18";
    src = fetchgit {
      url = "git://github.com/vimwiki/vimwiki";
      rev = "4831384ab9f1c40c9e433857d958c4d9a7beb8ec";
      sha256 = "1wjbsd37h5fxkkia90h708mmqisdj0kxzm9k97jm2zq36zngmd86";
    };
    dependencies = [];

  };

  vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vinegar-2016-06-30";
    src = fetchgit {
      url = "git://github.com/tpope/vim-vinegar";
      rev = "bd7f7b7929260072864462c04dde3b9f4c5e0d23";
      sha256 = "09shzlc9dagqlb5558nvm33b4bkk9cy34kp7zgnybphyy72wf31h";
    };
    dependencies = [];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2016-10-22";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "88688fe453038ac1ac26e31646cfbec50fca2fb7";
      sha256 = "1i46xjn0zklcrdp4yf856jpl7lwf14x4y67qhnc41q12rcvimvr5";
    };
    dependencies = [];

  };

  vim-jsdoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsdoc-2016-11-05";
    src = fetchgit {
      url = "git://github.com/heavenshell/vim-jsdoc";
      rev = "45c7c7cef440a29f7bf24436640413e3d5d578ff";
      sha256 = "0kr4p01pyrz9w7yfh50gsz6n60qvnqxsr1055hvsyx36nzw6l3za";
    };
    dependencies = [];

  };

  cpsm = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "cpsm-2016-09-21";
    src = fetchgit {
      url = "git://github.com/nixprime/cpsm";
      rev = "565ab53a66fa52c46d80adf6981b07f4bdffcb1d";
      sha256 = "125gcnqrg2276sp715q924cxwjxwsv3j4m0n1zj17w9srnpn4r1k";
    };
    dependencies = [];
    buildInputs = [
      python3
      stdenv
      cmake
      boost
      icu
    ];
    buildPhase = ''
      patchShebangs .
      export PY3=ON
      ./install.sh
    '';
  };
}
